import scipy.io as sio
from obspy import read
import os, sys
import argparse



info_string = '''
Python utility program to convert mseed file to mat (by Utpal Kumar)
'''

PARSER = argparse.ArgumentParser(description=info_string)

def convertmseed2mat(mseedfile, output_mat=None):
    
    st = read(mseedfile)

    filename, _ = os.path.splitext(mseedfile)
    if output_mat is None:
        outfilename = filename +".mat"
    else:
        outfilename = output_mat

    outdict = {}
    
    outdict['stats'] = {}
    outdict['data'] = {}
    
    for ii,tr in enumerate(st):
        outdict['stats'][f'stats_{ii}'] = {}
        for val in tr.stats:
            if val in ['starttime', 'endtime']:
                outdict['stats'][f'stats_{ii}'][val] = str(tr.stats[val])
            else:
                outdict['stats'][f'stats_{ii}'][val] = tr.stats[val]
        outdict['data'][f"data_{ii}"] = tr.data
    
        
    sio.savemat(
        outfilename, outdict
    )
    sys.stdout.write(f"Output file: {outfilename}\n")

if __name__ == '__main__':
    PARSER.add_argument("-inp",'--input_mseed', type=str, help="input mseed file, e.g. example_2020-05-01_IN.RAGD..BHZ.mseed", required=True)
    PARSER.add_argument("-out",'--output_mat', type=str, help="output mat file name, e.g. example_2020-05-01_IN.RAGD..BHZ.mat")
    

    args = PARSER.parse_args()
    mseedfile = args.input_mseed
    output_mat = args.output_mat
    convertmseed2mat(mseedfile, output_mat)


# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['miniseed2mat']

package_data = \
{'': ['*']}

install_requires = \
['obspy>=1.2.2,<2.0.0', 'scipy>=1.7.3,<2.0.0']

entry_points = \
{'console_scripts': ['mseed2mat = miniseed2mat.main:convertmseed2mat']}

setup_kwargs = {
    'name': 'miniseed2mat',
    'version': '0.1.6',
    'description': 'Analyzing MiniSEED seismic data in MATLAB',
    'long_description': '## Analyzing MiniSEED seismic data in MATLAB \n\nFor details on the usage, visit the earthinversion post: https://www.earthinversion.com/utilities/converting-mseed-data-to-mat-and-analyzing-in-matlab/\n\n## Output data structure\n\n- `stats` contains all the meta data information corresponding to each trace, and\n- `data` contain the time series data\n\n```\nmat_file.mat -> stats, data\nstats -> stats_0, stats_1, ...\ndata -> data_0, data_1, ...\n```\n',
    'author': 'Utpal Kumar',
    'author_email': 'utpalkumar50@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://www.earthinversion.com/utilities/converting-mseed-data-to-mat-and-analyzing-in-matlab/',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.9,<3.11',
}


setup(**setup_kwargs)
